import json
from datetime import datetime

class Kestra:
    def __init__(self):
        pass

    @staticmethod
    def _send(map):
        print("::" + json.dumps(map) + "::")

    @staticmethod
    def _metrics(name, type, value, tags=None):
        Kestra._send({
            "metrics": [
                {
                    "name": name,
                    "type": type,
                    "value": value,
                    "tags": tags or {}
                }
            ]
        })

    @staticmethod
    def outputs(map):
        Kestra._send({
            "outputs": map
        })

    @staticmethod
    def counter(name, value, tags=None):
        Kestra._metrics(name, "counter", value, tags)

    @staticmethod
    def timer(name, duration, tags=None):
        if callable(duration):
            start = datetime.now()
            duration()
            Kestra._metrics(name, "timer", (datetime.now().microsecond - start.microsecond) / 1000, tags)
        else:
            Kestra._metrics(name, "timer", duration, tags);



from setuptools import setup
from pathlib import Path
import re

setup(
    name='kestra',
    version="0.6.0", #re.search('(?m)^version=(.*)$', (Path(__file__).parent / 'gradle.properties').read_text()).group(1).replace('-SNAPSHOT', ''),
    package_dir={'': 'src'},
    include_package_data=True,
    python_requires='>=3',
    description='Kestra is an infinitely scalable orchestration and scheduling platform, creating, running, scheduling, and monitoring millions of complex pipelines.',
    long_description=(Path(__file__).parent / 'README.md').read_text(),
    long_description_content_type='text/markdown',
    url='https://kestra.io',
    author='Kestra',
    author_email='hello@kestra.io',
    license='Apache License 2.0',
    platforms='any',
    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
    ],
)
